#pragma once

#include <windows.h>

///////////////////////////////////////////////////////////////////
/// \brief High performance timing
///
/// This class provides high performance timing for single events 
///////////////////////////////////////////////////////////////////
class Timer
{
protected:
	LARGE_INTEGER start;
	LARGE_INTEGER stop;
	LARGE_INTEGER perfFreq;
	double offset;
	bool paused;

public:
    ///////////////////////////////////////////////////////////////
	/// \brief Default Constructor
	///////////////////////////////////////////////////////////////
	Timer(void);

    ///////////////////////////////////////////////////////////////
	/// \brief Deconstructor
	///////////////////////////////////////////////////////////////
	~Timer(void);

    ///////////////////////////////////////////////////////////////
	/// \brief Triggers the start of an event.
	///////////////////////////////////////////////////////////////
	void Start();

    ///////////////////////////////////////////////////////////////
	/// \brief Triggers the end of an event.
	///////////////////////////////////////////////////////////////
	double Tick();

    ///////////////////////////////////////////////////////////////
	/// \brief Returns the elapsed time.
	///////////////////////////////////////////////////////////////
	//double GetElapsed();

	inline void Pause(){
		offset = Tick();
		paused = true;
	}

	inline void Step(float amount){
		offset += amount;
	}

	inline bool Paused(){ return paused; }
};

